aboutsummaryrefslogtreecommitdiff
path: root/executer/exfldio.c
diff options
context:
space:
mode:
Diffstat (limited to 'executer/exfldio.c')
-rw-r--r--executer/exfldio.c7
1 files changed, 4 insertions, 3 deletions
diff --git a/executer/exfldio.c b/executer/exfldio.c
index cfb02213aa9c..37a678655172 100644
--- a/executer/exfldio.c
+++ b/executer/exfldio.c
@@ -202,12 +202,13 @@ AcpiExSetupRegion (
}
/*
* Exit now for SMBus address space, it has a non-linear address space
* and the request cannot be directly validated
*/
- if (RgnDesc->Region.SpaceId == ACPI_ADR_SPACE_SMBUS)
+ if (RgnDesc->Region.SpaceId == ACPI_ADR_SPACE_SMBUS ||
+ RgnDesc->Region.SpaceId == ACPI_ADR_SPACE_IPMI)
{
/* SMBus has a non-linear address space */
return_ACPI_STATUS (AE_OK);
}
@@ -202,12 +202,13 @@ AcpiExSetupRegion (
}
/*
- * Exit now for SMBus address space, it has a non-linear address space
+ * Exit now for SMBus or IPMI address space, it has a non-linear address space
* and the request cannot be directly validated
*/
@@ -202,12 +202,13 @@ AcpiExSetupRegion (
{
- /* SMBus has a non-linear address space */
+ /* SMBus or IPMI has a non-linear address space */
return_ACPI_STATUS (AE_OK);
}